﻿using System;
using System.Collections.Generic;
using System.Text;

namespace Alarm
{
    public class Alarm:Object
    {
        /// <summary>
        /// Статус события
        /// </summary>
        public enum Status
        {
            /// <summary>
            /// Не подтвержденное
            /// </summary>
            NACK,
            /// <summary>
            /// Периодическое
            /// </summary>
            PACK,
            /// <summary>
            /// Подтвержденное
            /// </summary>
            ACK
        }
        /// <summary>
        /// Приоритет события
        /// </summary>
        public enum Priority
        {
            /// <summary>
            /// Критическое
            /// </summary>
            Critical = 1,
            // Критическое, первый приоритет
            /// <summary>
            /// Мажорное
            /// </summary>
            Major = 2,
            // Мажорное, второй приоритет
            /// <summary>
            /// Минорное
            /// </summary>
            Minor = 3,
            // Минорное, третий приоритет
            /// <summary>
            /// Информационное, или без влияния
            /// </summary>
            Info = 4
            // Информация, четвертый приоритет 
            // или не требует действий
        }
        public enum Category
        {
            /// <summary>
            /// Внешнее
            /// </summary>
            Ext,
            // Внешние
            /// <summary>
            /// Внутреннее
            /// </summary>
            Intern,
            // Внутренние
            /// <summary>
            /// Не категоризированное
            /// </summary>
            Other
            // Не категоризированные
        }
        private Status _AlarmStatus = NACK;
        public DateTime DateACK;
        public DateTime DateUnACK;
        public DateTime DatePACK;
        public DateTime DateUnPACK;
        public DateTime DateStart;
        public DateTime DateCeasing;
        /// <summary>
        /// Статус
        /// </summary>
        public Status AlarmStatus        
        {
            get
            {
                return _AlarmStatus;
            }
            set
            {
                if (_AlarmStatus != value)
                {
                    switch (_AlarmStatus)
                    {
                        case Status.ACK:
                            DateUnACK = DateTime.Now;
                            break;
                        case Status.PACK:
                            DateUnPACK = DateTime.Now;
                            break;
                    }
                    switch (value)
                    {
                        case Status.ACK:
                            this.DateACK = DateTime.Now;
                            break;
                        case Status.PACK:
                            this.Date.PACK = DateTime.Now;
                            break;
                    }
                    _AlarmStatus = value;
                }
            }
        }
        private Category _AlarmCategory;
        /// <summary>
        /// Категория
        /// </summary>
        public Category AlarmCategory    
        {
            get
            {
                return _AlarmCategory;
            }
        }
        private bool _Ceasing = false;
        private int _PACKCount;
        /// <summary>
        /// Счетчик регистрации периодического события
        /// </summary>
        public int PACKCount             
        {
            get
            {
                return _PACKCount;
            }
        }
        /// <summary>
        /// Флаг завершения
        /// </summary>
        public bool Ceasing              
        {
            get
            {
                return _Ceasing;
            }
            set
            {
                if (_Ceasing != value)
                {
                    _Ceasing = value;
                    if (_Ceasing)
                    {
                        DateCeasing = DateTime.Now;
                    }
                    else
                    {
                        DateCeasing = null;
                        if (AlarmStatus == Status.PACK)
                        {
                            PACKCount++;
                        }
                    }
                }
            }
        }
        private Priority _AlarmPriority;
        /// <summary>
        /// Приоритет
        /// </summary>
        public Priority AlarmPriority    
        {
            get
            {
                return _AlarmPriority;
            }
        }
        public string AlarmObject;
        public string AlarmSource;
        public string AlarmInfo;
        public string AlarmDescr;

        /// <summary>
        /// Конструктор
        /// </summary>
        /// <param name="Cat">Категория</param>
        /// <param name="Prior">Приоритет</param>
        /// <param name="Ob">Объект</param>
        /// <param name="Source">Источник</param>
        /// <param name="Info">Краткое описание</param>
        /// <param name="Descr">Подробное описание</param>
        public Alarm(Category Cat,
                      Priority Prior,
                      string Ob,
                      string Source,
                      string Info,
                      string Descr)
        {
            _AlarmCategory = Cat;
            _AlarmPriority = Prior;
            AlarmObject = Ob;
            AlarmSource = Source;
            AlarmInfo = Info;
            AlarmDescr = Descr;
        }
    }
}
